# colorcluster

Reducing Color of pictures by KMeans clustering.

# Options

## input_fig_path
The file path of the image to be processed.

## color_num
Set the number of colors to be reduced. Default:8

## show_img
Pop up the processed picture when descripted.

## export_fig_path
Set the file path of output picture. Default:"result.jpg"

## export_color_array
Outputs the central color obtained by clustering in CSV format when descripted.

## export_array_path
Set  the file path of output of the above CSV file. Default:"array.csv"